@@ -1,6 +1,7 @@
 #!/usr/bin/python3
 
 import os
+import sys
 import subprocess
 import json
 import locale
@@ -26,11 +27,9 @@ from . import proxygsettings
 
 DEBUG = os.getenv("DEBUG") is not None
 
-
 def debug(msg):
     if DEBUG:
-        print(msg)
-
+        print(msg, file=sys.stderr)
 
 LANGUAGE_CODE = "C"
 try:
@@ -256,7 +255,7 @@ class Harvester:
             debug(f"Downloading from {r.request.url}")
             r.raise_for_status()
         except Exception as e:
-            print(f"Could not refresh json data for {self.spice_type}: {e}")
+            debug(f"Could not refresh json data for {self.spice_type}: {e}")
             return
 
         with open(self.index_file, "w", encoding="utf-8") as f:
@@ -288,7 +287,7 @@ class Harvester:
                                  params={"time": get_current_timestamp()})
                 r.raise_for_status()
             except Exception as e:
-                print(f"Could not get thumbnail for {uuid}: {e}")
+                debug(f"Could not get thumbnail for {uuid}: {e}")
                 return
 
             with open(paths.thumb_local_path, "wb", encoding="utf-8") as f:
@@ -359,9 +358,13 @@ class Harvester:
         self.updates = []
 
         for uuid in self.index_cache:
-            if uuid in self.meta_map and self._spice_has_update(uuid):
-                update = SpiceUpdate(self.spice_type, uuid, self.index_cache[uuid], self.meta_map[uuid])
-                self.updates.append(update)
+            try:
+                if uuid in self.meta_map and self._spice_has_update(uuid):
+                    update = SpiceUpdate(self.spice_type, uuid, self.index_cache[uuid], self.meta_map[uuid])
+                    self.updates.append(update)
+            except Exception as e:
+                debug(f"Error checking updates for {uuid}: {e}")
+                raise
 
         return self.updates
 
@@ -374,11 +377,13 @@ class Harvester:
     def _install_by_uuid(self, uuid):
         action = "upgrade" if uuid in self.meta_map else "install"
 
+        error_message = None
+        uuid = uuid
         try:
             item = self.index_cache[uuid]
         except KeyError:
             debug(f"Can't install {uuid} - it doesn't seem to exist on the server")
-            return
+            raise
 
         paths = SpicePathSet(item, spice_type=self.spice_type)
 
@@ -389,8 +394,8 @@ class Harvester:
                              params={"time": get_current_timestamp()})
             r.raise_for_status()
         except Exception as e:
-            print(f"Could not download zip for {uuid}: {e}")
-            return
+            debug(f"Could not download zip for {uuid}: {e}")
+            raise
 
         try:
             tmp_name = None
@@ -409,6 +414,7 @@ class Harvester:
                 self._load_metadata()
         except Exception as e:
             debug(f"couldn't install: {e}")
+            raise
 
     def _install_from_folder(self, folder, base_folder, uuid, from_spices=False):
         contents = os.listdir(folder)
